mysql.constants.field_types

Package mysql :: Package constants :: Module field_types |
[hide private]
[frames] | no frames]

# Module field_types

Identifiers of different field types.

These field type identifiers are used in a variety of places, such as the mysql.result.Field object.

Variables | [hide private]
`` | BIGINT = `8` BIGINT field.
`` | BIT = `16` BIT field (MySQL 5.0.3 and up).
`` | BLOB = `252` BLOB or TEXT field (use max_length to determine the maximum length).
`` | CHAR = `254`
`` | DATE = `10` DATE field.
`` | DATETIME = `12` DATETIME field.
`` | DECIMAL = `0` DECIMAL or NUMERIC field.
`` | DOUBLE = `5` DOUBLE or REAL field.
`` | ENUM = `247` ENUM field.
`` | FLOAT = `4` FLOAT field.
`` | GEOMETRY = `255` Spatial field.
`` | INTEGER = `3` INTEGER field.
`` | MEDIUMINT = `9` MEDIUMINT field.
`` | NEWDECIMAL = `246` Precision math DECIMAL or NUMERIC field (MySQL 5.0.3 and up).
`` | SET = `248` SET field.
`` | SMALLINT = `2` SMALLINT field.
`` | STRING CHAR field.
`` | TIME = `11` TIME field.
`` | TIMESTAMP = `7` TIMESTAMP field.
`` | TINYINT = `1` TINYINT field.
`` | VARCHAR = `253`
`` | VAR_STRING VARCHAR field.
`` | YEAR = `13` YEAR field.
`` | __version__ = `'$Revision: 1.3 $'`

Variables Details | [hide private]

    ### BIGINT BIGINT field. Value:
        8

    ### BIT BIT field (MySQL 5.0.3 and up). Value:
        16

    ### BLOB BLOB or TEXT field (use max_length to determine the maximum length). Value:
        252

    ### CHAR Value:
        254

    ### DATE DATE field. Value:
        10

    ### DATETIME DATETIME field. Value:
        12

    ### DECIMAL DECIMAL or NUMERIC field. Value:
        0

    ### DOUBLE DOUBLE or REAL field. Value:
        5

    ### ENUM ENUM field. Value:
        247

    ### FLOAT FLOAT field. Value:
        4

    ### GEOMETRY Spatial field. Value:
        255

    ### INTEGER INTEGER field. Value:
        3

    ### MEDIUMINT MEDIUMINT field. Value:
        9

    ### NEWDECIMAL Precision math DECIMAL or NUMERIC field (MySQL 5.0.3 and up). Value:
        246

    ### SET SET field. Value:
        248

    ### SMALLINT SMALLINT field. Value:
        2

### STRING CHAR field.

    ### TIME TIME field. Value:
        11

    ### TIMESTAMP TIMESTAMP field. Value:
        7

    ### TINYINT TINYINT field. Value:
        1

    ### VARCHAR Value:
        253

### VAR_STRING VARCHAR field.

    ### YEAR YEAR field. Value:
        13

    ### __version__ Value:
        '$Revision: 1.3 $'